//////////////////////////////////////////////////////////////////////////
// This is a demo lcdproc client for the icons of the Futuba            //
// MDM166A VFD display. LCDd has to be running.                         //
//                                                                      //
// It will set the icons using the following command line arguments:    //
//                                                                      //
// Argument 1: Single icon bitmask                                      //
//                                                                      //
// Bit    Funktion                                                      //
// 0      Play                                                          //
// 1      Pause                                                         //
// 2      Record                                                        //
// 3      Message                                                       //
// 4      @                                                             //
// 5      Mute                                                          //
// 6      WLAN tower                                                    //
// 7      Volume (the word)                                             //
//                                                                      //
// Example: 1 will set the Play icon only, 10 will set the Pause and    //
//          the Message icons, 255 sets all icons.                      //
//                                                                      //
// Argument 2: Volume (0..28)                                           //
//                                                                      //
// Argument 3: WLAN strength (0..3)                                     //
//                                                                      //
// (C) 2010 Christoph Rasim (christoph@rasim.net)                       //
//                                                                      //
// This tool is released under the GPL. See file COPYING in this        //
// package for further details.                                         //
//////////////////////////////////////////////////////////////////////////

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include "sockets.h"

int sock = -1;
int port = 23666;
int clearflag = 0;
char* host = "127.0.0.1";

void print_help();

int
main(int argc, char *argv[])
{	
    char cmd[64];
    int icons = 0, volume = 0, wlan = 0,c =0;
	if(argc<2){
		print_help();
		return;
		}
	while ((c = getopt (argc, argv, "hcH:p:i:w:v:")) != -1)
		switch(c){
			case'h':
				print_help();
				return EXIT_SUCCESS;
			case 'c':
				clearflag = 1;
				break;
			case 'H':
				host = optarg;
				break;
			case 'p':
				port = atoi(optarg);
				break;
			case 'i':
				icons = atoi(optarg);
				if(icons<0||icons>255)
					icons=0;
				break;
			case 'w':
				wlan = atoi(optarg);
				if(wlan<0||wlan>3)
					wlan = 0;
				break;
			case 'v':
				volume = atoi(optarg);
				if(volume<0 ||volume >28)
					volume =0;
				break;
			case '?':
				if(optopt == 'H'||optopt=='p'||optopt=='i'||optopt=='w'||optopt=='v')
					fprintf(stderr,"Option -%c requires an argument.\n",optopt);
				else if(isprint(optopt))
					fprintf(stderr,"Unknown option '-%c'.\n",optopt);
				else
					fprintf(stderr,"Unknown option '\\x%x'.\n",optopt);
				return -1;
			default:
				abort();
		}
	if(clearflag>0){
		icons =0;
		volume=0;
		wlan=0;
	}
				
			
		
    //if (argc>1) icons = atoi(argv[1]);
    //if ((icons<0) || (icons>255)) icons=0;
    //if (argc>2) volume = atoi(argv[2]);
    //if ((volume<0) || (volume>28)) volume=0;
    //if (argc>3) wlan = atoi(argv[3]);
    //if ((wlan<0) || (wlan>3)) wlan=0;

	// Connect to the server...
	sock = sock_connect(host, port);
	if (sock < 0) {
		printf("Error connecting to LCD server localhost on port 13666.\n");
		return -1;
	}

	sock_send_string(sock, "hello\n");
	usleep(150000);			// wait for the server to say hi.

    // Set VFD state
	sprintf(cmd, "output %d\n", (volume<<8)+(wlan<<13)+icons);
    sock_send(sock, cmd, strlen(cmd));

    // Wait for driver
    usleep(150000);
    sock_close(sock);
}

void print_help(){
	printf("Usage: mdmicons <options>/n/nOptions are:\n\t-h\tPrint this usage information\n\t-p\tLCDd port\n\t-H\tLCDd host\n\t-i\ticon bitmask 0-255\n\t-v\tvolume level 0-28\n\t-w\twlan level 0-3\n\t-c\tclear all icons (equivalent to -i0 -v0 -w0)\n\nSupported argument formats are -p13667 and -p 13667,\n but not -p=13776\n\nThis program was written and is (C) by Christoph Rasim (christoph@rasim.net)\nand was given a good once-over by Thomas Fischer (feyn@gmx.de)\n\nThis program is distributed in the hope that it will be usefull\nbut without implicit or explicit warranty and is used at your own risk\n\nThis software is distributed under the GPL.");
}
	
